<?php
/**
 * Various utilies used throughout.
 *
 * @package Tasty_Pins
 */

namespace Tasty_Pins;

/**
 * Various utilies used throughout.
 */
class Utils {

	/**
	 * Applies given attributes to <img> with the content.
	 *
	 * @param string  $content    Existing content.
	 * @param array   $attributes Attributes to apply.
	 * @param boolean $override   Whether or not to override the existing values.
	 * @return string
	 */
	public static function apply_img_attributes( $content, $attributes, $override ) {
		if ( false === stripos( $content, '<img ' ) || empty( $attributes ) ) {
			return $content;
		}
		$content = preg_replace_callback(
			'#(<img)([^>]+)(>)#',
			function( $matches ) use ( $attributes, $override ) {
				$inner = $matches[2];
				foreach ( $attributes as $attribute => $value ) {
					if ( $override ) {
						$inner = preg_replace(
							'#(' . $attribute . '=["\'])([^"\']+)(["\'])#',
							'$1' . $value . '$3',
							$inner
						);
					}
					if ( false === stripos( $inner, $attribute ) ) {
						$inner = ' ' . $attribute . '="' . esc_attr( $value ) . '"' . $inner;
					}
				}
				return $matches[1] . $inner . $matches[3];
			},
			$content
		);
		return $content;
	}

}
