<?php
/**
 * Handles the Tasty Pins integration with ELementor.
 *
 * @package Tasty_Pins
 */

namespace Tasty_Pins\Integrations;

use Tasty_Pins\Frontend;
use Tasty_Pins\Utils;

/**
 * Handles the Tasty Pins integration with ELementor.
 */
class Elementor {

	/**
	 * Post meta key used to store Pinterest Text.
	 *
	 * @var string
	 */
	const TEXT_KEY = 'tp_pinterest_text';

	/**
	 * Post meta key used to store Pinterest Title.
	 *
	 * @var string
	 */
	const TITLE_KEY = 'tp_pinterest_title';

	/**
	 * Post meta key used to store Pinterest Repin ID.
	 *
	 * @var string
	 */
	const REPIN_ID_KEY = 'tp_pinterest_repin_id';

	/**
	 * Post meta key used to store Pinterest No Pin attribute.
	 *
	 * @var string
	 */
	const NO_PIN_KEY = 'tp_pinterest_no_pin';

	/**
	 * Renders before the Image block's image_section ends.
	 *
	 * @param object $instance Elementor instance.
	 */
	public static function action_image_before_section_end( $instance ) {
		$instance->add_control(
			self::TITLE_KEY,
			array(
				'label'       => __( 'Pinterest Title', 'tasty-pins' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'label_block' => true,
				'default'     => '',
			)
		);
		$instance->add_control(
			self::TEXT_KEY,
			array(
				'label'   => __( 'Pinterest Text', 'tasty-pins' ),
				'type'    => \Elementor\Controls_Manager::TEXTAREA,
				'default' => '',
			)
		);
		$instance->add_control(
			self::REPIN_ID_KEY,
			array(
				'label'   => __( 'Pinterest Repin ID', 'tasty-pins' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => '',
			)
		);
		$instance->add_control(
			self::NO_PIN_KEY,
			array(
				'label'   => __( 'Disable Pinning', 'tasty-pins' ),
				'type'    => \Elementor\Controls_Manager::SWITCHER,
				'default' => '',
			)
		);
	}

	/**
	 * Filters the rendering of the widget.
	 *
	 * @param string $content  Existing widget content.
	 * @param object $instance Elementor instance.
	 * @return string $content
	 */
	public static function filter_widget_render_content( $content, $instance ) {
		if ( 'image' === $instance->get_name() ) {
			$attributes = array();
			$mapping    = array(
				self::TITLE_KEY    => Frontend::TITLE_ATTRIBUTE,
				self::TEXT_KEY     => Frontend::TEXT_ATTRIBUTE,
				self::REPIN_ID_KEY => Frontend::REPIN_ID_ATTRIBUTE,
			);
			$settings   = $instance->get_settings_for_display();
			foreach ( $mapping as $key => $attribute ) {
				$value = $settings[ $key ];
				if ( ! empty( $value ) ) {
					$attributes[ $attribute ] = $value;
				}
			}
			if ( ! empty( $settings[ self::NO_PIN_KEY ] ) ) {
				$attributes[ Frontend::NOPIN_ATTRIBUTE ] = 'nopin';
			}
			$content = Utils::apply_img_attributes( $content, $attributes, true );
		}
		// Applies default text and forced images.
		$content = Frontend::filter_the_content_early( $content );
		return $content;
	}
}
